{% extends 'base.html' %} {% load custom_tags_and_filters %} {% block title %}Update a news story{% endblock %} {% block content %}

# Update a news story

## {{ story.title }}

{% csrf_token %}
{% button type="delete" submit=True value="Archive this news story" icon="glyphicon-folder-close" %}

{{ story.all_content|safe|linebreaksbr }}

{% csrf_token %}
Keep this news story at the top of the news feed
{% button type="save" name="publish" value="Publish" %}
{% endblock %}